==> reactome.db_1.0.36.zip: reactome.db/doc/reactome.R <==
###################################################
### chunk number 1: setup0
###################################################
#line 55 "reactome.Rnw"
options(continue=" ", prompt="R> ", width=72L)


###################################################
### chunk number 2: setup
###################################################
#line 59 "reactome.Rnw"
library("reactome.db")


###################################################
### chunk number 3: objects
###################################################
#line 65 "reactome.Rnw"
ls("package:reactome.db")


###################################################
### chunk number 4: Question #1
###################################################
#line 74 "reactome.Rnw"
library("reactome.db")


###################################################
### chunk number 5: QAlisting
###################################################
#line 83 "reactome.Rnw"
qcdata = capture.output(reactome())
head(qcdata, 20)


###################################################
### chunk number 6: mapcounts eval=FALSE
###################################################
## #line 91 "reactome.Rnw"
## reactomeMAPCOUNTS


###################################################
### chunk number 7: envApiDemo1
###################################################
#line 99 "reactome.Rnw"
all_reactomeIds <- ls(reactomePATHID2EXTID)
length(all_reactomeIds)

set.seed(0xa1beef)
reactomeIds <- sample(all_reactomeIds, 3)
reactomeIds


###################################################
### chunk number 8: envApiDemo2
###################################################
#line 110 "reactome.Rnw"
reactomePATHID2EXTID[[reactomeIds[1]]]
reactomePATHID2EXTID$"1163762"

pathwayNames <- unlist(mget(reactomeIds, reactomePATHID2NAME))
pathwayNames


###################################################
### chunk number 9: helpDemo eval=FALSE
###################################################
## #line 121 "reactome.Rnw"
## ?reactomeEXTID2PATHID


###################################################
### chunk number 10: Question #2
###################################################
#line 129 "reactome.Rnw"
mget(reactomeIds, reactomeREACTOMEID2GO, ifnotfound=NA)[1:2]


###################################################
### chunk number 11: Question #4
###################################################
#line 139 "reactome.Rnw"
count.mappedLkeys(reactomeREACTOMEID2GO)
length(reactomeREACTOMEID2GO) - count.mappedLkeys(reactomeREACTOMEID2GO)
mappedLkeys(reactomeREACTOMEID2GO)[1]
toTable(reactomeREACTOMEID2GO["1008200"])


###################################################
### chunk number 12: SessionInfo
###################################################
#line 149 "reactome.Rnw"
sessionInfo()

==> reactome.db_1.0.38.zip: reactome.db/doc/reactome.R <==
### R code from vignette source 'reactome.Rnw'

###################################################
### code chunk number 1: setup0
###################################################
options(continue=" ", prompt="R> ", width=72L)


###################################################
### code chunk number 2: setup
###################################################
library("reactome.db")


###################################################
### code chunk number 3: objects
###################################################
ls("package:reactome.db")


###################################################
### code chunk number 4: Question #1
###################################################
library("reactome.db")


###################################################
### code chunk number 5: QAlisting
###################################################
qcdata = capture.output(reactome())
head(qcdata, 20)


###################################################
### code chunk number 6: mapcounts (eval = FALSE)
###################################################
## reactomeMAPCOUNTS


###################################################
### code chunk number 7: envApiDemo1
###################################################
all_reactomeIds <- ls(reactomePATHID2EXTID)
length(all_reactomeIds)

set.seed(0xa1beef)
reactomeIds <- sample(all_reactomeIds, 3)
reactomeIds


###################################################
### code chunk number 8: envApiDemo2
###################################################
reactomePATHID2EXTID[[reactomeIds[1]]]
reactomePATHID2EXTID$"1163762"

pathwayNames <- unlist(mget(reactomeIds, reactomePATHID2NAME))
pathwayNames


###################################################
### code chunk number 9: helpDemo (eval = FALSE)
###################################################
## ?reactomeEXTID2PATHID


###################################################
### code chunk number 10: getPathwaysForSpecies
###################################################
pathways <- toTable(reactomePATHNAME2ID)
pathwaysSelectedSpecies <- pathways[grep("Homo sapiens: ", iconv(pathways$path_name)), ]


###################################################
### code chunk number 11: Question #2
###################################################
mget(reactomeIds, reactomeREACTOMEID2GO, ifnotfound=NA)[1:2]


###################################################
### code chunk number 12: Question #4
###################################################
count.mappedLkeys(reactomeREACTOMEID2GO)
length(reactomeREACTOMEID2GO) - count.mappedLkeys(reactomeREACTOMEID2GO)
mappedLkeys(reactomeREACTOMEID2GO)[1]
toTable(reactomeREACTOMEID2GO["1008200"])


###################################################
### code chunk number 13: SessionInfo
###################################################
sessionInfo()
